<a id="readme-top"></a> 



<!-- PROJECT SUMMARY -->
<br />
<div align="center">
  <img src="https://i.imgur.com/TIFNTsG.png" alt="Logo">
  <br />
  <p align="center">
    A CometD client, updated for Python 3.10
    <br />
    <a href="aiocometd.readthedocs.io/"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="#getting-started">Getting Started</a>
    ·
    <a href="aiocometd.readthedocs.io/">Documentation</a>
    ·
    <a href="https://github.com/Kieran-Lock/aiocometd-noloop/blob/main/LICENSE">License</a>
  </p>
</div>



<!-- ABOUT THE PROJECT -->
## About the Project

aiocometd-noloop is an updated version of the [aiocometd Python package](https://github.com/robertmrk/aiocometd), which is a python client for [CometD](https://cometd.org/).  
  
This package is updated for compatibility with Python 3.10, allowing for usage with modern more modern Python features and projects.



<!-- GETTING STARTED -->
## Getting Started

aiocometd-noloop is available on [PyPI](https://pypi.org/project/aiocometd-noloop/). To use it in your project, run:

```
pip install aiocometd-noloop
```



<!-- BASIC USAGE EXAMPLES -->
## Basic Usage

See the original repository for usage examples and any further details.



<!-- LICENSE -->
## License

Distributed under the MIT License. See [LICENSE](https://github.com/Kieran-Lock/aiocometd-noloop/blob/main/LICENSE) for further details.

<p align="right">(<a href="#readme-top">Back to Top</a>)</p>
